#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-simple
version:              1.23.1.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.1.0-ird2pPrQ9PHqQkYH3ptnF
key:                  haskell-src-exts-simple-1.23.1.0-ird2pPrQ9PHqQkYH3ptnF
license:              MIT
copyright:            2016-2024, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  a554376af12f97a1ed4da33d7e4ec92c
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-simple-1.23.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.1.0-ird2pPrQ9PHqQkYH3ptnF
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-8fZ1MJCbx62Bq7ESjXiRC6

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

